::: randomsymplectic.dnary_arithmetic
    options:
        show_root_heading: true
        show_source: false
        group_by_category: false
        show_category_heading: true
        show_if_no_docstring: false
        docstring_section_style: spacy
        members:
        - int_to_dnary
        - dnary_to_int
        - dnary_inverse
